ardt.preprocessors.filters.NK2ECGProcess.NK2ECGProcess
======================================================

.. currentmodule:: ardt.preprocessors.filters.NK2ECGProcess

.. autoclass:: NK2ECGProcess

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NK2ECGProcess.__init__
      ~NK2ECGProcess.process_signal
      ~NK2ECGProcess.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NK2ECGProcess.context
   
   